@@ -40,6 +40,7 @@ func (fc *File) Init(cacheFilePath string, persist bool) {
 
 	for key, co := range list {
 		if co.Expired() {
+			log.Debug("skipping expired cache key:", key)
 			continue
 		}
 
@@ -77,10 +78,16 @@ func (fc *File) Get(key string) (string, bool) {
 
 // sets the value for the given key with a duration
 func (fc *File) Set(key, value string, duration Duration) {
+	seconds := duration.Seconds()
+
+	if seconds == 0 {
+		return
+	}
+
 	fc.cache.Set(key, &Entry{
 		Value:     value,
 		Timestamp: time.Now().Unix(),
-		TTL:       duration.Seconds(),
+		TTL:       seconds,
 	})
 
 	fc.dirty = true
