@@ -9,18 +9,28 @@ type base struct {
 	props properties.Properties
 	env   runtime.Environment
 
-	Output string `json:"Text"`
+	Segment *Segment `json:"segment"`
+}
+
+type Segment struct {
+	Text  string `json:"text"`
+	Index int    `json:"index"`
 }
 
 func (s *base) Text() string {
-	return s.Output
+	return s.Segment.Text
 }
 
 func (s *base) SetText(text string) {
-	s.Output = text
+	s.Segment.Text = text
+}
+
+func (s *base) SetIndex(index int) {
+	s.Segment.Index = index
 }
 
 func (s *base) Init(props properties.Properties, env runtime.Environment) {
+	s.Segment = &Segment{}
 	s.props = props
 	s.env = env
 }
